@@ -160,7 +160,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.2.773");
+    setStatus("Using qgvdial version 0.2.774");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -1376,7 +1376,7 @@ MainWindow::refreshRegisteredNumbers ()
                     SLOT   (gotRegisteredPhone (const GVRegisteredNumber &)));
             Q_ASSERT(rv);
             rv = false;
-            qWarning ("Failed to retrieve registered contacts!!");
+            qWarning ("Get registered numbers failed at the start!!!");
             break;
         }
 
